@@ -1,20 +1,30 @@
 mod add_matrices;
+mod aliases;
 mod cholesky_factor;
 mod copy_matrix;
 mod eigen_decomp;
 mod inverse;
 mod mat_mat_mul;
-mod matrix;
+mod mat_max_abs_diff;
+mod mat_t_mat_mul;
+mod matrix_norm;
+mod num_matrix;
 mod pseudo_inverse;
+mod scale_matrix;
 mod sv_decomp;
 mod update_matrix;
 pub use crate::matrix::add_matrices::*;
+pub use crate::matrix::aliases::*;
 pub use crate::matrix::cholesky_factor::*;
 pub use crate::matrix::copy_matrix::*;
 pub use crate::matrix::eigen_decomp::*;
 pub use crate::matrix::inverse::*;
 pub use crate::matrix::mat_mat_mul::*;
-pub use crate::matrix::matrix::*;
+pub use crate::matrix::mat_max_abs_diff::*;
+pub use crate::matrix::mat_t_mat_mul::*;
+pub use crate::matrix::matrix_norm::*;
+pub use crate::matrix::num_matrix::*;
 pub use crate::matrix::pseudo_inverse::*;
+pub use crate::matrix::scale_matrix::*;
 pub use crate::matrix::sv_decomp::*;
 pub use crate::matrix::update_matrix::*;
