@@ -1,7 +1,7 @@
-use russell_lab::*;
+use russell_lab::{add_vectors, mat_vec_mul, solve_lin_sys, vector_norm, Matrix, NormVec, StrError, Vector};
 
 #[test]
-fn test_lin_sys() -> Result<(), &'static str> {
+fn test_lin_sys() -> Result<(), StrError> {
     const TARGET: f64 = 1234.0;
     for m in [0, 5, 7, 12_usize] {
         // prepare matrix and rhs
@@ -14,8 +14,8 @@ fn test_lin_sys() -> Result<(), &'static str> {
         }
 
         // take copies
-        let a_copy = a.get_copy();
-        let b_copy = b.get_copy();
+        let a_copy = a.clone();
+        let b_copy = b.clone();
 
         // solve linear system: b := a⁻¹⋅b == x
         solve_lin_sys(&mut b, &mut a)?;
@@ -34,7 +34,7 @@ fn test_lin_sys() -> Result<(), &'static str> {
         let mut diff = Vector::new(m);
         mat_vec_mul(&mut rhs, 1.0, &a_copy, &b)?;
         add_vectors(&mut diff, 1.0, &rhs, -1.0, &b_copy)?;
-        assert_eq!(diff.norm(NormVec::Max), 0.0);
+        assert_eq!(vector_norm(&diff, NormVec::Max), 0.0);
     }
     Ok(())
 }
