@@ -1,7 +1,7 @@
-use russell_lab::*;
+use russell_lab::{mat_mat_mul, mat_vec_mul, matrix_norm, vector_norm, Matrix, NormMat, NormVec, StrError, Vector};
 
 #[test]
-fn test_mat_vec_mul() -> Result<(), &'static str> {
+fn test_mat_vec_mul() -> Result<(), StrError> {
     // v  :=  a  ⋅ u
     // (m)  (m,n) (n)
     for m in [0, 7, 15_usize] {
@@ -11,9 +11,9 @@ fn test_mat_vec_mul() -> Result<(), &'static str> {
             let mut v = Vector::new(m);
             mat_vec_mul(&mut v, 1.0, &a, &u)?;
             if m == 0 {
-                assert_eq!(v.norm(NormVec::Max), 0.0);
+                assert_eq!(vector_norm(&v, NormVec::Max), 0.0);
             } else {
-                assert_eq!(v.norm(NormVec::Max), n as f64);
+                assert_eq!(vector_norm(&v, NormVec::Max), n as f64);
             }
         }
     }
@@ -21,7 +21,7 @@ fn test_mat_vec_mul() -> Result<(), &'static str> {
 }
 
 #[test]
-fn test_mat_mat_mul() -> Result<(), &'static str> {
+fn test_mat_mat_mul() -> Result<(), StrError> {
     //   c  :=  a  ⋅  b
     // (m,n)  (m,k) (k,n)
     for m in [0, 5, 7_usize] {
@@ -32,9 +32,9 @@ fn test_mat_mat_mul() -> Result<(), &'static str> {
                 let b = Matrix::filled(k, n, 1.0);
                 mat_mat_mul(&mut c, 1.0, &a, &b)?;
                 if m == 0 || n == 0 {
-                    assert_eq!(c.norm(NormMat::Max), 0.0);
+                    assert_eq!(matrix_norm(&c, NormMat::Max), 0.0);
                 } else {
-                    assert_eq!(c.norm(NormMat::Max), k as f64);
+                    assert_eq!(matrix_norm(&c, NormMat::Max), k as f64);
                 }
             }
         }
